==> pegasus-support-1.6.3-sources.jar: com/thebeastshop/support/vo/lottery/LotteryScrollRecordVO.java <==
package com.thebeastshop.support.vo.lottery;

import java.io.Serializable;

/**
 * 中奖滚动记录
 * Created by feilong.gao on 2016/12/6.
 */
public class LotteryScrollRecordVO implements Serializable{

    /**
     * serialVersionUID
     */
    private static final long serialVersionUID = 1L;
    /**
     * 中奖人
     */
    private String memberNickName;
    /**
     * 奖品类型
     */
    private String type;
    /**
     * 奖品类型描述
     */
    private String typeDesc;
    /**
     * 奖品值
     */
    private String value;
    /**
     * 优化券模板名字
     */
    private String couponSampleName;

    public String getMemberNickName() {
        return memberNickName;
    }

    public void setMemberNickName(String memberNickName) {
        this.memberNickName = memberNickName;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getTypeDesc() {
        return typeDesc;
    }

    public void setTypeDesc(String typeDesc) {
        this.typeDesc = typeDesc;
    }

    public String getValue() {
        return value;
    }

    public void setValue(String value) {
        this.value = value;
    }

    public String getCouponSampleName() {
        return couponSampleName;
    }

    public void setCouponSampleName(String couponSampleName) {
        this.couponSampleName = couponSampleName;
    }

    @Override
    public String toString() {
        final StringBuffer sb = new StringBuffer("LotteryScrollRecordVO{");
        sb.append("memberNickName='").append(memberNickName).append('\'');
        sb.append(", type='").append(type).append('\'');
        sb.append(", typeDesc='").append(typeDesc).append('\'');
        sb.append(", value='").append(value).append('\'');
        sb.append(", couponSampleName='").append(couponSampleName).append('\'');
        sb.append('}');
        return sb.toString();
    }
}

==> pegasus-support-2.7.5-sources.jar: com/thebeastshop/support/vo/lottery/LotteryScrollRecordVO.java <==
package com.thebeastshop.support.vo.lottery;

import java.io.Serializable;

/**
 * 中奖滚动记录
 * Created by feilong.gao on 2016/12/6.
 */
public class LotteryScrollRecordVO implements Serializable{

    /**
     * serialVersionUID
     */
    private static final long serialVersionUID = 1L;
    /**
     * 中奖人
     */
    private String memberNickName;
    /**
     * 奖品类型
     */
    private String type;
    /**
     * 奖品类型描述
     */
    private String typeDesc;
    /**
     * 奖品值
     */
    private String value;
    /**
     * 优化券模板名字
     */
    private String couponSampleName;

    /**
     * 奖项名称
     */
    private String awardName;

    public String getMemberNickName() {
        return memberNickName;
    }

    public void setMemberNickName(String memberNickName) {
        this.memberNickName = memberNickName;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getTypeDesc() {
        return typeDesc;
    }

    public void setTypeDesc(String typeDesc) {
        this.typeDesc = typeDesc;
    }

    public String getValue() {
        return value;
    }

    public void setValue(String value) {
        this.value = value;
    }

    public String getCouponSampleName() {
        return couponSampleName;
    }

    public void setCouponSampleName(String couponSampleName) {
        this.couponSampleName = couponSampleName;
    }

    public String getAwardName() {
        return awardName;
    }

    public void setAwardName(String awardName) {
        this.awardName = awardName;
    }

    @Override
    public String toString() {
        return "LotteryScrollRecordVO{" +
                "memberNickName='" + memberNickName + '\'' +
                ", type='" + type + '\'' +
                ", typeDesc='" + typeDesc + '\'' +
                ", value='" + value + '\'' +
                ", couponSampleName='" + couponSampleName + '\'' +
                ", awardName='" + awardName + '\'' +
                '}';
    }
}
